import {} from "@netlify/functions";
import { NetlifyIntegrationClient } from "./vendor/integration_client.js";
import { INTEGRATION_API_URL } from "./vendor/constants.js";
// TODO(ndhoule): Divorce this from Request? This is sort of purpose-built for tRPC right now but we
// should be able to use it in non-tRPC normal request handlers
export const createNetlifySDKContext = ({ req, }) => {
    const netlifyToken = req.headers.get("Nf-UIExt-Netlify-Token");
    const slug = req.headers.get("Nf-UIExt-Extension-Slug");
    const netlifyApiUrl = process.env["NETLIFY_API_BASE_URL"] ?? `${INTEGRATION_API_URL}/api/v1`;
    // FIXME(ndhoule): Allow specifying these types, they come from the NetlifyIntegration class
    const client = new NetlifyIntegrationClient(netlifyToken ?? "", slug ?? "", // FIXME(ndhoule): This ain't great, we really should bail out slug is not available
    { netlifyApiUrl });
    return {
        auth: {
            netlifyToken,
            providerToken: req.headers.get("Nf-UIExt-Provider-Token"),
        },
        client,
        // TODO(ndhoule): I think it's better to congeal this together into a single "ownerId" field.
        // We'd want to begin doing this way up in netlify-react-ui so this concept doesn't bleed down
        // into the extension (like it has here). In fact, we can probably eliminate the need to pass
        // down slug/siteId/teamId entirely.
        //
        // Plus, as a note to self: Some of this is encoded into the netlify token, and it's encoded as
        // an "ownerId":
        // {
        //   authorized_scopes: 'site:read,site:write,env:read,env:write,env:delete',
        //   netlify_auth_token: ' {{ token }}',
        //   owner_id: '{{ ownerId }}', // this is the siteId for site-specific integrations, teamId for team-specific integrations
        //   integration_slug: 'supabase',
        //   exp: {{ expiry }},
        //   iat: {{ issuedat }}
        // }
        //
        // The one piece of information not encoded into the token that we'd lose out on is whether or
        // not we want to prefer siteId or teamId. But I think we always prefer siteId over teamId,
        // because the former is not always present while the latter is?
        siteId: req.headers.get("Nf-UIExt-Site-Id"),
        teamId: req.headers.get("Nf-UIExt-Team-Id"),
        // ownerId:
        //   req.headers.get("Nf-UIExt-Site-Id") ??
        //   req.headers.get("Nf-UIExt-Team-Id"),
    };
};
//# sourceMappingURL=sdk_context.js.map